0.9.9 API documentation: perpendicular.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

perpendicular.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18 #include "../gtx/projection.hpp"
19
20 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
21 # ifndef GLM_ENABLE_EXPERIMENTAL
22 # pragma message("GLM: GLM_GTX_perpendicular is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
23 # else
24 # pragma message("GLM: GLM_GTX_perpendicular extension included")
25 # endif
26 #endif
27
28 namespace glm
29 {
32
35 template<typename genType>
36 GLM_FUNC_DECL genType perp(genType const& x, genType const& Normal);
37
39 }//namespace glm
40
41 #include "perpendicular.inl"
glm::perp
GLM_FUNC_DECL genType perp(genType const &x, genType const &Normal)
Projects x a perpendicular axis of Normal.
glm
Definition: common.hpp:20